import os
import yaml
import validators

def parse_config(config_file):
    if os.path.isfile(config_file):
        print("Config file exists at " + config_file)
        with open(config_file, "r") as stream:
            try:
                config = yaml.safe_load(stream)
                # Validate types
                if type(config['robin_email']) is not str:
                    print("robin_email is not a string")
                    exit(1)
                if type(config['robin_password']) is not str:
                    print("robin_password is not a string")
                    exit(1)
                if not validators.url(config['api_url']):
                    print("api_url is not a valid URL")
                    exit(1)
                return config
            except yaml.YAMLError as exc:
                print(exc)

    else:
        print("Config file is missing at " + config_file)



import os
import argparse
from .validate_radar_type import validate_radar_type
from .validate_version_name import validate_version_name
from .create_zip import create_zip
from .push_software import push_software
from .remove_zip import remove_zip
from .parse_config import parse_config
from .create_config import create_config
from .check_upload_file import check_upload_file

def arg_parse(config_file):
    parser = argparse.ArgumentParser(
        description = 'Robin Radar Systems Software Uploader',
        usage       = 'python3 robin_sd_upload [options]', 
        prog        = 'Robin Radar Systems Software Uploader',
        epilog      = 'To report any bugs or issues, please visit: https://support.robinradar.systems'
    )

    parser.add_argument('--check', action='store_true', help='ensure all prerequisites are met')
    parser.add_argument('--config', action='store_true', help='create/view a config file (/.config/robin/software_deployment.yaml)')
    parser.add_argument('--upload', action='store_true', help='upload software to the server: python3 robin_sd_upload --upload --type=radar_type --version=version_name')

    parser = argparse.ArgumentParser(description='argument parses for upload script.')
    parser.add_argument("--type", type=str, help="radar type")
    parser.add_argument("--version", type=str, help="version name")
    parser.add_argument("--filepath", type=str, help="file path")

    args = parser.parse_args()
    radarType = args.type
    version_name = args.version
    filepath = args.filepath

    if args.check:
        parse_config(config_file)
        check_upload_file(filepath)
        exit(0)
    if args.config:
        create_config(config_file)
        exit(0)
    elif args.upload:
        parse_config(config_file)
        check_upload_file(filepath)

        print("given type: ", radarType)
        print("given version_name: ", version_name)
        print("given filepath: ", filepath)

        version_dir_to_upload= os.path.join(filepath, version_name)
        zipped_file_path = os.path.join(filepath, version_name + '.zip')

        print('version_dir_to_upload: ', version_dir_to_upload)
        print('zipped_file_path: ', zipped_file_path)

        validate_radar_type(radarType)
        validate_version_name(version_name)
        create_zip(zipped_file_path, version_name)
        print(push_software(zipped_file_path, radarType, version_name))
        # logging or sending log to server
        remove_zip(zipped_file_path)
    else:
        parser.print_help()
        exit(1)








import yaml
import os
import subprocess

editor = os.environ.get('EDITOR', 'nano')

def create_config(config_file):
    if os.path.isfile(config_file):
        print("Config file already exists at " + config_file)
        subprocess.run([editor, config_file])
        return 0
    else:
        print("Creating config file at " + config_file)
        config = {
            "robin_email": "your email address",
            "robin_password": "your password",
            "api_url": "api url"
        }
        # create the directory if it doesn't exist
        os.makedirs(os.path.dirname(config_file), exist_ok=True)
        # write the config file
        with open(config_file, "w") as stream:
            yaml.dump(config, stream)
        print("Config file created at " + config_file)
        # open the config file in the default editor
        subprocess.run([editor, config_file])
        return 0



import validators

def validate_version_name(version_name):
    if validators.length(version_name, min=1, max=20) == False:
        print("Version name is not valid: " + version_name)
        exit()
    else:
        print("Version name is valid: " + version_name)
        return version_name


# It configures all your package’s contents and all sorts of auxiliary information.
# You can then create a distribution of your package using the following command:
# python setup.py sdist
# This will create a dist directory containing a distribution archive file in the .tar.gz format.
# You can then install your package using pip install:
# pip install /path/to/my_package-0.1.tar.gz

from setuptools import setup

with open("README.md") as file:
    long_description = file.read()

setup(
    name="robin_sd_upload",
    packages=["robin_sd_upload"],
    install_requires=["validators>=0.18.2", "PyYAML>=5.4.1", "requests>=2.25.1", "zipfile36>=0.1.3", "nano>=0.1.0"],
    entry_points={
    'console_scripts': [
        'robin_sd_upload = robin_sd_upload.__main__:main',
    ],
    },
    version="0.1.14",
    license="MIT",
    description="Package to upload files to the Robin Radar API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Robin Radar Systems",
    author_email="tivadar.kamondy@robinradar.com",
    url="https://bitbucket.org/robin-radar-systems/sd-api-upload-pip-package.git",
    keywords=["python", "robin", "radar", "download", "software", "sd"]
)



import validators

def validate_radar_type(radarType):
    radarTypearray = ["elvira", "iris", "birdradar"]
    if validators.length(radarType, min=1, max=50) == False:
        print("Radar type is not valid: " + radarType)
        exit()
        #check if radar type is in the array
    if radarType not in radarTypearray:
            print("Radar type is not valid: " + radarType)
            exit()
    else:
        print("Radar type is valid: " + radarType)
        return radarType